==> haskell-unicode-transforms-0.2.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.2.1
id: unicode-transforms-0.2.1-EeeQ6pTxIlHKoXYgUimGP0
key: unicode-transforms-0.2.1-EeeQ6pTxIlHKoXYgUimGP0
license: BSD3
copyright: 2016 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 8.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
author: Harendra Kumar
exposed: True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
abi: 33a714d86fd2929cf4d79f735ceaf986
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-transforms-0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-transforms-0.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/unicode-transforms-0.2.1
hs-libraries: HSunicode-transforms-0.2.1-EeeQ6pTxIlHKoXYgUimGP0
depends:
    base-4.9.0.0 bitarray-0.0.1.1-9oSzik18SiaLBtzGdFPDHQ
    bytestring-0.10.8.1 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.3.1
id: unicode-transforms-0.3.1-Df3p1huTwHvCahHVs9Hbyg
key: unicode-transforms-0.3.1-Df3p1huTwHvCahHVs9Hbyg
license: BSD3
copyright: 2016-2017 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 9.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
author: Harendra Kumar
exposed: True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
abi: 4d14eab2ae930be090053c2f8d55a555
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/unicode-transforms-0.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/unicode-transforms-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/unicode-transforms-0.3.1
hs-libraries: HSunicode-transforms-0.3.1-Df3p1huTwHvCahHVs9Hbyg
depends:
    base-4.9.1.0 bitarray-0.0.1.1-ISZdXKCdEZI2kyFA42ACof
    bytestring-0.10.8.1 text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
